@@ -31,11 +31,11 @@ MUSTACHE_SUBSTITUTIONS = {
 
 # Lazy substitutions: 'submit' only
 if "submit" in sys.argv[0]:
-    WR_NAME = "wr_name"
-    TASK_NUMBER = "task_number"
-    TASK_GROUP_NUMBER = "task_group_number"
-    TASK_COUNT = "task_count"
-    TASK_GROUP_COUNT = "task_group_count"
+    L_WR_NAME = "wr_name"
+    L_TASK_NUMBER = "task_number"
+    L_TASK_GROUP_NUMBER = "task_group_number"
+    L_TASK_COUNT = "task_count"
+    L_TASK_GROUP_COUNT = "task_group_count"
 
 # Type annotations for Mustache type substitutions
 NUMBER_SUB = "num:"
@@ -215,6 +215,9 @@ def load_jsonnet_file_with_mustache_substitutions(filename: str, prefix="") -> D
     ) as preprocessed_filename:
         dict_data = json_loads(evaluate_file(preprocessed_filename))
 
+    # Secondary processing after Jsonnet expansion
+    process_mustache_substitutions(dict_data, prefix)
+
     return dict_data
 
 
@@ -229,7 +232,13 @@ def load_toml_file_with_mustache_substitutions(filename: str, prefix: str = "")
     # Add any Mustache substitutions in the TOML file before processing the
     # file as a whole
     try:
-        add_substitutions(config[COMMON_SECTION][VARIABLES])
+        # Convert all values to strings before adding
+        add_substitutions(
+            {
+                var_name: str(var_value)
+                for var_name, var_value in config[COMMON_SECTION][VARIABLES].items()
+            }
+        )
     except KeyError:
         pass
 
