@@ -27,6 +27,7 @@ from yellowdog_client.model import (
 
 from yd_commands.args import ARGS_PARSER
 from yd_commands.compact_json import CompactJSONEncoder
+from yd_commands.config_keys import NAME, TASK_GROUPS, TASKS
 from yd_commands.object_utilities import Item
 
 JSON_INDENT = 2
@@ -205,7 +206,13 @@ def print_numbered_object_list(
     print()
 
 
-def print_numbered_strings(objects: List[str]):
+def print_numbered_strings(objects: List[str], override_quiet: bool = False):
+    """
+    Print a simple list of strings with numbering
+    """
+    if ARGS_PARSER.quiet and override_quiet is False:
+        return
+
     table = []
     for index, obj in enumerate(objects):
         table.append([index + 1, ":", obj])
@@ -273,7 +280,6 @@ def print_worker_pool(
         "requirementTemplateUsage": Json.dump(crtu),
     }
     print_json(wp_data)
-    print_log("Dry run: Complete")
 
 
 class WorkRequirementSnapshot:
@@ -298,10 +304,10 @@ class WorkRequirementSnapshot:
         Add the list of Tasks to a named Task Group within the
         Work Requirement. Cumulative.
         """
-        for task_group in self.wr_data["taskGroups"]:
-            if task_group["name"] == task_group_name:
-                task_group["tasks"] = task_group.get("tasks", [])
-                task_group["tasks"] += [Json.dump(task) for task in tasks]
+        for task_group in self.wr_data[TASK_GROUPS]:
+            if task_group[NAME] == task_group_name:
+                task_group[TASKS] = task_group.get(TASKS, [])
+                task_group[TASKS] += [Json.dump(task) for task in tasks]
                 return
 
     def print(self):
